summaryrefslogtreecommitdiffstats
path: root/kbarcode/dsrichtext.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbarcode/dsrichtext.h')
-rw-r--r--kbarcode/dsrichtext.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kbarcode/dsrichtext.h b/kbarcode/dsrichtext.h
index 8381419..8c56b56 100644
--- a/kbarcode/dsrichtext.h
+++ b/kbarcode/dsrichtext.h
@@ -31,13 +31,13 @@ class DSRichText;
/** This class represents one word,
* formated with a font, a color and an
- * tqalignment.
+ * alignment.
*/
struct formated_word {
TQString text;
TQFont font;
TQColor color;
- int tqalignment;
+ int alignment;
bool line;
};
@@ -138,10 +138,10 @@ class DSRichText {
bool parseParagraph();
/** remove <p> and </p> from the TQString @p t and return it.
* This function is also responsible for getting the
* correct tqalignment of the paragraph.
*/
- TQString parseParagraphTag( const TQString & t, int* tqalignment );
- /** parse the align attribute of a <p> tag and return the corresponding TQt tqalignment value.
+ TQString parseParagraphTag( const TQString & t, int* alignment );
+ /** parse the align attribute of a <p> tag and return the corresponding TQt alignment value.
*/
int parseAlignment( const TQString & align );
/** parse the css style attribute of a <span> tag and return a matching TQFont for these
@@ -150,7 +150,7 @@ class DSRichText {
TQFont parseStyle( const TQString & s, TQColor* color );
TQString parse( const TQString & t, const TQString & find, const TQString & end, int start );
void parseWords( const TQString & t, formated_word* w, WordList* words );
- void initFormat( formated_word* f, int tqalignment );
+ void initFormat( formated_word* f, int alignment );
void initLine( TQValueList<formated_line>* l );
void updateSpacing( TQValueList<formated_line>* l, TQFontMetrics* fm );
/** draw the line @p line justified as blockquote
@@ -138,10 +138,10 @@ class DSRichText {
/** remove <p> and </p> from the TQString @p t and return it.
* This function is also responsible for getting the
- * correct tqalignment of the paragraph.
+ * correct alignment of the paragraph.
*/